@@ -1,23 +1,17 @@
 <?php
 /**
+ * Copyright 2009-2012 Horde LLC (http://www.horde.org/)
+ *
  * @category   Horde
  * @package    Support
  * @subpackage UnitTests
- * @copyright  1999-2009 Horde LLC (http://www.horde.org/)
  * @license    http://www.horde.org/licenses/bsd
  */
 
 /**
- * Prepare the test setup.
- */
-require_once dirname(__FILE__) . '/Autoload.php';
-
-/**
- * @group      support
  * @category   Horde
  * @package    Support
  * @subpackage UnitTests
- * @copyright  1999-2009 Horde LLC (http://www.horde.org/)
  * @license    http://www.horde.org/licenses/bsd
  */
 class Horde_Support_TimerTest extends PHPUnit_Framework_TestCase
@@ -38,12 +32,14 @@ class Horde_Support_TimerTest extends PHPUnit_Framework_TestCase
 
     /**
      * test getting the finish time before starting the timer
-     * @expectedException Exception
      */
     public function testNotStartedYetThrowsException()
     {
         $t = new Horde_Support_Timer();
-        $t->pop();
+        try {
+            $t->pop();
+            $this->fail('Expected Exception');
+        } catch (Exception $e) {}
     }
 
 }
